# ActivityStreams Derive
__derive macros for ActivityStreams__

## Usage
Add the required crates to your `Cargo.toml`
```toml
# Cargo.toml

activitystreams-derive = "0.1"
activitystreams-traits = "0.1"
serde = "1.0"
serde_derive = "1.0"
serde_json = "1.0"
```

And then in your project
```rust
#[macro_use]
extern crate activitystreams_derive;
extern crate activitystreams_traits;
extern crate serde;
#[macro_use]
extern crate serde_derive;
extern crate serde_json;

use activitystreams_traits::{Link, Object};

/// Using the UnitString derive macro
///
/// This macro implements Serialize and Deserialize for the given type, making this type
/// represent the string "SomeKind" in JSON.
#[derive(Clone, Debug, Default, UnitString)]
#[activitystreams(SomeKind)]
pub struct MyKind;

/// Using the Properties derive macro
///
/// This macro generates getters and setters for the associated fields.
#[derive(Clone, Debug, Default, Deserialize, Serialize, Properties)]
#[serde(rename_all = "camelCase")]
pub struct MyProperties {
    /// Derive getters and setters for @context with Link and Object traits.
    #[serde(rename = "@context")]
    #[activitystreams(ab(Object, Link))]
    pub context: Option<serde_json::Value>,

    /// Use the UnitString MyKind to enforce the type of the object by "SomeKind"
    pub kind: MyKind,

    /// Derive getters and setters for required_key with String type.
    ///
    /// In the Activity Streams spec, 'functional' means there can only be one item for this
    /// key. This means all fields not labeled 'functional' can also be serialized/deserialized
    /// as Vec<T>.
    #[activitystreams(concrete(String), functional)]
    pub required_key: serde_json::Value,
}
```

## Contributing
Feel free to open issues for anything you find an issue with. Please note that any contributed code will be licensed under the GPLv3.

## License

Copyright © 2018 Riley Trautman

ActivityStreams Derive is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

ActivityStreams Derive is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. This file is part of ActivityStreams Derive.

You should have received a copy of the GNU General Public License along with ActivityStreams Derive. If not, see [http://www.gnu.org/licenses/](http://www.gnu.org/licenses/).
